@@ -189,7 +189,7 @@ echo "Please edit /etc/postgresql/x.y/main/pg_hba.conf as needed."
 echo ""
 echo "Typically you will need a line like this:"
 echo ""
-echo " local   samegroup   +gm-logins   md5"
+echo " local   samerole    +gm-logins   md5"
 echo ""
 echo "For details refer to the GNUmed documentation at:"
 echo ""
